from fastapi import APIRouter, Depends
from sqlalchemy.orm import Session
from app.database import get_db
from app.models.board_notice import BoardNotice

router = APIRouter(prefix="/api/notice", tags=["notice"])

@router.get("/list")
async def get_notice_list(db: Session = Depends(get_db)):
    """
    공지사항 목록 조회
    """
    base_url = "../img/"

    # 공지사항 조회 (최대 5개, 조회수 오름차순)
    notices = db.query(BoardNotice).filter(
        BoardNotice.board_type == "notice"
    ).order_by(BoardNotice.view_cnt.asc()).limit(5).all()

    # 결과 변환
    result = []
    for notice in notices:
        title = notice.title[:120]  # 제목 최대 길이 제한
        thum_url = f"{base_url}{notice.sumfile_url.replace('/board/upload/', '')}" if notice.sumfile_url else None
        main_url = f"{base_url}{notice.file_url.replace('/board/upload/', '')}" if notice.file_url else None
        result.append({
            "idx": notice.idx,
            "title": title,
            "file_width": notice.file_width,
            "thum_url": thum_url,
            "main_url": main_url,
        })

    return {"status": "success", "data": result}
