# app/routes/check_availability.py
from fastapi import APIRouter, Depends, HTTPException
from sqlalchemy.orm import Session
from app.database import get_db
from app.utils.validators import check_id_exists, check_nickname_exists, check_bank_number_exists

router = APIRouter(prefix="/api/check", tags=["Availability"])

@router.get("/id")
async def check_id_availability(join_id: str, db: Session = Depends(get_db)):
    if not join_id:
        raise HTTPException(status_code=400, detail="회원 ID는 필수 항목입니다.")

    if check_id_exists(join_id, db):
        return {"status": "error", "message": "이미 사용 중인 ID입니다.", "checkID": 0}
    return {"status": "success", "message": "사용 가능한 ID입니다.", "checkID": "y"}

@router.get("/nickname")
async def check_nickname_availability(join_nick: str, db: Session = Depends(get_db)):
    if not join_nick:
        raise HTTPException(status_code=400, detail="닉네임은 필수 항목입니다.")

    if check_nickname_exists(join_nick, db):
        return {"status": "error", "message": "이미 사용 중인 닉네임입니다.", "checkNick": 0}
    return {"status": "success", "message": "사용 가능한 닉네임입니다.", "checkNick": "y"}

@router.get("/bank")
async def check_bank_number_availability(bank_num: str, db: Session = Depends(get_db)):
    if not bank_num:
        raise HTTPException(status_code=400, detail="계좌번호는 필수 항목입니다.")

    if check_bank_number_exists(bank_num, db):
        return {"status": "error", "message": "이미 사용 중인 계좌번호입니다.", "checkBankNum": 0}
    return {"status": "success", "message": "사용 가능한 계좌번호입니다.", "checkBankNum": "y"}
