from fastapi import APIRouter, Depends, HTTPException
from sqlalchemy.orm import Session
from sqlalchemy import desc
from app.database import get_db
from app.models.terms import TermsOfService

router = APIRouter(prefix="/api/terms", tags=["Terms of Service"])

@router.get("/")
async def get_latest_terms_of_service(db: Session = Depends(get_db)):
    """
    최신 약관 정보를 반환하는 API 엔드포인트
    """
    try:
        # 최신 약관 가져오기
        latest_terms = db.query(TermsOfService).order_by(desc(TermsOfService.last_updated)).first()
        if not latest_terms:
            raise HTTPException(status_code=404, detail="약관 정보를 찾을 수 없습니다.")

        return {
            "status": "success",
            "data": {
                "title": latest_terms.title,
                "content": latest_terms.content,
                "last_updated": latest_terms.last_updated.strftime("%Y-%m-%d %H:%M:%S")
            }
        }

    except Exception as e:
        raise HTTPException(status_code=500, detail=f"데이터를 가져오는 중 오류가 발생했습니다: {str(e)}")
