from fastapi import APIRouter, Depends, HTTPException
from sqlalchemy.orm import Session
from app.database import get_db
from app.models.member import Member
from app.models.member_info import MembersInfo

router = APIRouter(prefix="/api/user", tags=["User"])


@router.get("/info")
async def get_user_info(user_id: str, db: Session = Depends(get_db)):
    """
    특정 유저의 정보를 반환하는 API 엔드포인트
    """
    if not user_id:
        raise HTTPException(status_code=400, detail="유효하지 않은 사용자 ID입니다.")

    try:
        # `members`와 `members_info` 조인
        user_data = db.query(
            Member.id.label("id"),
            Member.nick.label("nick"),
            Member.site_lvl.label("site_lvl"),
            Member.active.label("active"),
            Member.userclass.label("userclass"),
            MembersInfo.bank.label("bank"),
            MembersInfo.bank_name.label("bank_name"),
            MembersInfo.bank_num.label("bank_num"),
            MembersInfo.phone.label("phone")
        ).join(
            MembersInfo, Member.id == MembersInfo.mem_id
        ).filter(
            Member.id == user_id
        ).first()

        # 결과가 없는 경우
        if not user_data:
            raise HTTPException(status_code=404, detail="해당 유저를 찾을 수 없습니다.")

        # 반환 데이터 형식
        result = {
            "id": user_data.id,
            "nick": user_data.nick,
            "site_lvl": user_data.site_lvl,
            "active": user_data.active,
            "userclass": user_data.userclass,
            "bank": user_data.bank,
            "bank_name": user_data.bank_name,
            "bank_num": user_data.bank_num,
            "phone": user_data.phone,
        }

        return {"status": "success", "data": result}

    except Exception as e:
        raise HTTPException(status_code=500, detail=f"데이터를 가져오는 중 오류가 발생했습니다: {str(e)}")
